@@ -15,7 +15,7 @@ mod utils;
 use self::{
   configmaps::KubeConfigMap,
   contexts::KubeContext,
-  deployments::KubeDeployments,
+  deployments::KubeDeployment,
   key_binding::DEFAULT_KEYBINDING,
   metrics::{GroupBy, QtyByQualifier},
   models::{LogsState, ScrollableTxt, StatefulTable, TabsState},
@@ -48,13 +48,13 @@ pub enum ActiveBlock {
   ReplicaSets,
   Namespaces,
   Describe,
+  Yaml,
   Contexts,
   Utilization,
 }
 
 #[derive(Clone, PartialEq, Debug)]
 pub enum RouteId {
-  Error,
   Home,
   Contexts,
   Utilization,
@@ -95,7 +95,7 @@ pub struct Data {
   pub config_maps: StatefulTable<KubeConfigMap>,
   pub stateful_sets: StatefulTable<KubeStatefulSet>,
   pub replica_sets: StatefulTable<KubeReplicaSet>,
-  pub deployments: StatefulTable<KubeDeployments>,
+  pub deployments: StatefulTable<KubeDeployment>,
   pub logs: LogsState,
   pub describe_out: ScrollableTxt,
   pub metrics: StatefulTable<(Vec<String>, Option<QtyByQualifier>)>,
@@ -256,8 +256,10 @@ impl App {
   }
 
   pub fn reset(&mut self) {
+    self.tick_count = 0;
     self.api_error = String::new();
     self.data = Data::default();
+    self.route_home();
   }
 
   // Send a network event to the network thread
@@ -311,7 +313,6 @@ impl App {
   }
 
   pub fn handle_error(&mut self, e: anyhow::Error) {
-    self.push_navigation_stack(RouteId::Error, ActiveBlock::Empty);
     self.api_error = e.to_string();
   }
 
@@ -361,7 +362,7 @@ impl App {
   }
 
   pub fn refresh(&mut self) {
-    self.refresh = true
+    self.refresh = true;
   }
 
   pub async fn on_tick(&mut self, first_render: bool) {
@@ -373,13 +374,15 @@ impl App {
       }
       self.dispatch(IoEvent::GetKubeConfig).await;
       self.dispatch_cmd(IoCmdEvent::GetCliInfo).await;
-      // call these once  to pre-load data
+      // call these once to pre-load data
       self.dispatch(IoEvent::GetPods).await;
       self.dispatch(IoEvent::GetServices).await;
       self.dispatch(IoEvent::GetConfigMaps).await;
       self.dispatch(IoEvent::GetStatefulSets).await;
       self.dispatch(IoEvent::GetReplicaSets).await;
       self.dispatch(IoEvent::GetDeployments).await;
+
+      self.refresh = false;
     }
     // make network requests only in intervals to avoid hogging up the network
     if self.tick_count == 0 || self.is_routing {
@@ -409,6 +412,7 @@ impl App {
             }
             ActiveBlock::Logs => {
               if !self.is_streaming {
+                // do not tail to avoid duplicates
                 self.dispatch_stream(IoStreamEvent::GetPodLogs(false)).await;
               }
             }
@@ -428,13 +432,116 @@ impl App {
     if self.tick_count > self.tick_until_poll {
       self.tick_count = 0; // reset ticks
     }
+  }
+}
 
-    // route to home after all network requests to avoid showing error again
-    if self.refresh {
-      if !first_render {
-        self.route_home();
-      }
-      self.refresh = false;
-    }
+#[cfg(test)]
+mod tests {
+
+  use tokio::sync::mpsc;
+
+  use super::*;
+
+  #[tokio::test]
+  async fn test_on_tick_first_render() {
+    let (sync_io_tx, mut sync_io_rx) = mpsc::channel::<IoEvent>(500);
+    let (sync_io_cmd_tx, mut sync_io_cmd_rx) = mpsc::channel::<IoCmdEvent>(500);
+
+    let mut app = App {
+      tick_until_poll: 2,
+      io_tx: Some(sync_io_tx),
+      io_cmd_tx: Some(sync_io_cmd_tx),
+      ..App::default()
+    };
+
+    assert_eq!(app.tick_count, 0);
+    // test first render
+    app.on_tick(true).await;
+    assert_eq!(sync_io_rx.recv().await.unwrap(), IoEvent::GetKubeConfig);
+    assert_eq!(sync_io_rx.recv().await.unwrap(), IoEvent::GetPods);
+    assert_eq!(sync_io_rx.recv().await.unwrap(), IoEvent::GetServices);
+    assert_eq!(sync_io_rx.recv().await.unwrap(), IoEvent::GetConfigMaps);
+    assert_eq!(sync_io_rx.recv().await.unwrap(), IoEvent::GetStatefulSets);
+    assert_eq!(sync_io_rx.recv().await.unwrap(), IoEvent::GetReplicaSets);
+    assert_eq!(sync_io_rx.recv().await.unwrap(), IoEvent::GetDeployments);
+    assert_eq!(sync_io_rx.recv().await.unwrap(), IoEvent::GetNamespaces);
+    assert_eq!(sync_io_rx.recv().await.unwrap(), IoEvent::GetNodes);
+    assert_eq!(sync_io_rx.recv().await.unwrap(), IoEvent::GetPods);
+
+    assert_eq!(sync_io_cmd_rx.recv().await.unwrap(), IoCmdEvent::GetCliInfo);
+
+    assert!(!app.refresh);
+    assert!(!app.is_routing);
+    assert_eq!(app.tick_count, 1);
+  }
+  #[tokio::test]
+  async fn test_on_tick_refresh_tick_limit() {
+    let (sync_io_tx, mut sync_io_rx) = mpsc::channel::<IoEvent>(500);
+    let (sync_io_stream_tx, mut sync_io_stream_rx) = mpsc::channel::<IoStreamEvent>(500);
+    let (sync_io_cmd_tx, mut sync_io_cmd_rx) = mpsc::channel::<IoCmdEvent>(500);
+
+    let mut app = App {
+      tick_until_poll: 2,
+      tick_count: 2,
+      refresh: true,
+      io_tx: Some(sync_io_tx),
+      io_stream_tx: Some(sync_io_stream_tx),
+      io_cmd_tx: Some(sync_io_cmd_tx),
+      ..App::default()
+    };
+
+    assert_eq!(app.tick_count, 2);
+    // test first render
+    app.on_tick(false).await;
+    assert_eq!(sync_io_rx.recv().await.unwrap(), IoEvent::RefreshClient);
+    assert_eq!(sync_io_rx.recv().await.unwrap(), IoEvent::GetKubeConfig);
+    assert_eq!(sync_io_rx.recv().await.unwrap(), IoEvent::GetPods);
+    assert_eq!(sync_io_rx.recv().await.unwrap(), IoEvent::GetServices);
+    assert_eq!(sync_io_rx.recv().await.unwrap(), IoEvent::GetConfigMaps);
+    assert_eq!(sync_io_rx.recv().await.unwrap(), IoEvent::GetStatefulSets);
+    assert_eq!(sync_io_rx.recv().await.unwrap(), IoEvent::GetReplicaSets);
+    assert_eq!(sync_io_rx.recv().await.unwrap(), IoEvent::GetDeployments);
+
+    assert_eq!(
+      sync_io_stream_rx.recv().await.unwrap(),
+      IoStreamEvent::RefreshClient
+    );
+    assert_eq!(sync_io_cmd_rx.recv().await.unwrap(), IoCmdEvent::GetCliInfo);
+
+    assert!(!app.refresh);
+    assert!(!app.is_routing);
+    assert_eq!(app.tick_count, 0);
+  }
+  #[tokio::test]
+  async fn test_on_tick_routing() {
+    let (sync_io_tx, mut sync_io_rx) = mpsc::channel::<IoEvent>(500);
+    let (sync_io_stream_tx, mut sync_io_stream_rx) = mpsc::channel::<IoStreamEvent>(500);
+
+    let mut app = App {
+      tick_until_poll: 2,
+      tick_count: 2,
+      is_routing: true,
+      refresh: false,
+      io_tx: Some(sync_io_tx),
+      io_stream_tx: Some(sync_io_stream_tx),
+      ..App::default()
+    };
+
+    app.push_navigation_stack(RouteId::Home, ActiveBlock::Logs);
+
+    assert_eq!(app.tick_count, 2);
+    // test first render
+    app.on_tick(false).await;
+    assert_eq!(sync_io_rx.recv().await.unwrap(), IoEvent::GetNamespaces);
+    assert_eq!(sync_io_rx.recv().await.unwrap(), IoEvent::GetNodes);
+
+    assert_eq!(
+      sync_io_stream_rx.recv().await.unwrap(),
+      IoStreamEvent::GetPodLogs(false)
+    );
+
+    assert!(!app.refresh);
+    assert!(!app.is_routing);
+    assert_eq!(app.tick_count, 0);
   }
 }
