@@ -9,11 +9,12 @@ use kube::{
 use tokio::sync::MutexGuard;
 
 use super::{
+  models::ResourceToYaml,
   utils::{self, UNKNOWN},
   App,
 };
 
-#[derive(Clone)]
+#[derive(Clone, Default)]
 pub struct NodeMetrics {
   pub name: String,
   pub cpu: String,
@@ -36,6 +37,7 @@ pub struct KubeNode {
   pub cpu_percent: String,
   pub mem_percent: String,
   pub age: String,
+  k8s_obj: Node,
 }
 
 static NODE_LABEL_PREFIX: &str = "node-role.kubernetes.io/";
@@ -161,10 +163,17 @@ impl KubeNode {
       mem_a: utils::mem_to_mi(mem_a.unwrap_or_default()),
       cpu_percent,
       mem_percent,
+      k8s_obj: node.to_owned(),
     }
   }
 }
 
+impl ResourceToYaml<Node> for KubeNode {
+  fn get_k8s_obj(&self) -> &Node {
+    &self.k8s_obj
+  }
+}
+
 impl NodeMetrics {
   pub fn from_api(metric: &DynamicObject, app: &MutexGuard<App>) -> Self {
     let name = metric.metadata.name.clone().unwrap_or_default();
